<?php

	/**
	 * Captcha module 
	 *
	 * This UR (user registration) verification module uses the  
	 * FreeCap library to implement registration captchas
	 *
	 * To implement, set the following in wikka.config.php:
	 *		'UR_validation_modules' => 'URCaptchaModule'
	 * (If combined with other modules, separate each module with a
	 * comma.)
	 *
	 * @see libs/userregistration.class.php
	 * @see URAuth, URAuthTmpl
	 * @link http://wikkawiki.org/FreeCap
	 * @link http://www.puremango.co.uk/cm_php_captcha_script_113.php
	 *
	 * @license http://www.gnu.org/copyleft/gpl.html GNU General Public License
	 * @filesource
	 *
	 * @author {@link http://wikkawiki.org/BrianKoontz Brian Koontz} 
	 * @author {@link http://wikkawiki.org/YodaHome Yodahome}
	 *	(Original Wikka implementation of FreeCap)
	 * @author {@link http://www.puremango.co.uk Howard Yeend}
	 *  (freecap implementation)
	 *
	 * @copyright Copyright 2008 {@link http://wikkawiki.org/CreditsPage Wikka Development Team}
	 */

	if (!defined('CAPTCHA_LABEL')) define('CAPTCHA_LABEL', "Type the letters in the picture:");
	if (!defined('CAPTCHA_NO_READ')) define('CAPTCHA_NO_READ', "If you cannot read the word,");
	if (!defined('CAPTCHA_NO_READ_CLICK_HERE')) define('CAPTCHA_NO_READ_CLICK_HERE', "click here");
	if (!defined('CAPTCHA_EMPTY_PROMPT')) define('CAPTCHA_EMPTY_PROMPT', "<em class='error'>You entered none of the letters.  Please do so.</em>");
	if (!defined('CAPTCHA_WRONG_RESPONSE')) define('CAPTCHA_WRONG_RESPONSE', "<em class='error'>You entered the wrong letters, please try again.</em>");

	include_once('libs/userregistration.class.php');

	class URCaptchaModule extends URAuthTmpl
	{
		var $wakka;
		var $error;

		function URCaptchaModule(&$wakka)
		{
			$this->URAuthTmpl($wakka);	
			$this->wakka = $wakka;
			$this->error = '';
		}

		function URAuthTmplDisplay()
		{
			if(empty($_SESSION['freecap_word_hash']))
			{
				setcookie("freecap", session_name(), 0, '/');
				$this->_displayCaptcha();
			}
			else if(empty($_POST['word']))
			{
				$this->error = CAPTCHA_EMPTY_PROMPT;
				$this->_displayCaptcha();
			}
			else if($_SESSION['hash_func'](strtolower($_POST['word']))!=$_SESSION['freecap_word_hash'])
			{
				$this->error = CAPTCHA_WRONG_RESPONSE;
				$this->_displayCaptcha();
			}
		}

		function URAuthTmplVerify()
		{
			if(isset($_SESSION['hash_func']) && $_SESSION['hash_func'](strtolower($_POST['word']))==$_SESSION['freecap_word_hash'])
			{   // reset freecap session vars to prevent spoofing
				$_SESSION['freecap_attempts'] = 0;
				$_SESSION['freecap_word_hash'] = false;
				return true;
			}
			return false;
		}

		function _displayCaptcha()
		{
			// Display captcha
?>
<br/>
<script language="javascript">
<!--
function new_freecap()
{
	// loads new freeCap image
	if(document.getElementById)
	{
		// extract image name from image source (i.e. cut off
		// ?randomness)
		thesrc = document.getElementById("freecap").src;
		thesrc = thesrc.substring(0,thesrc.lastIndexOf(".")+4);
		// add ?(random) to prevent browser/isp caching
		document.getElementById("freecap").src =
thesrc+"?"+Math.round(Math.random()*100000);
	} else {
		alert("Sorry, cannot autoreload freeCap image\nSubmit the form and a new freeCap will be loaded");
	}
}
//-->
</script>
<div id="captcha">
<img src="libs/UR/URCaptchaModule/freecap/freecap.php" id="freecap"/><br/>
<?php echo CAPTCHA_NO_READ ?><a href="<?php echo $this->wakka->Href('', 'UserSettings'); ?>" onClick="this.blur();new_freecap();return false;"> <?php echo CAPTCHA_NO_READ_CLICK_HERE ?>.</a>
</div>
<p><?php echo $this->error; ?>
<p>
<label for="confpassword"><?php echo CAPTCHA_LABEL ?></label>
<input id="confpassword" name="word" type="text" size="40" />
<br/><br/>
<?php

		}
	}
?>
